@@ -14,6 +14,14 @@ def encode_signal(signal, value):
 
 def decode_signal(signal, value):
     value = (value >> signal.start) & bitmask(signal.length)
+
+    #if "se" in signal.name:
+    #    print(signal)
+
+    if signal.type == 'signed':
+        value = int(value)
+        if (value >> (signal.length - 1)) == 1:
+            value = - ((value ^ bitmask(signal.length)) + 1)
     return (value * signal.scale) + signal.offset
 
 
